"use client"
import React, { useEffect, useState } from 'react'
import styles from './item.module.css'
import Input from '@/components/base/input/Input';
import closeIcon from '@/public/icons/red-x-10333.svg';
import Image from 'next/image';
import { TodoListItems } from '@/Types/todoTypes';


interface ItemProps {
    data: TodoListItems
    onDelete: (id: number) => void;
    updateTask: (id: number, task: string, isCompleted: boolean) => void;
}

const Item: React.FC<ItemProps> = ({ onDelete, updateTask, data }) => {
    const { id, task, isCompleted } = data;
    const [isChecked, setisChecked] = useState(isCompleted);

    useEffect(() => {
        setisChecked(isCompleted)
    }, [isCompleted])

    const handleChange = async () => {
        await updateTask(id, task, !isCompleted)
        setisChecked(!isChecked)
    }

    const handleItem = (e: React.ChangeEvent<HTMLInputElement>) => {
        updateTask?.(id, e.target.value, isCompleted)
    }

    const handleClose = () => {
        onDelete?.(id)
    }

    return (
        <div className={styles.item}>
            <input type='checkbox' checked={isChecked} onChange={handleChange} className={styles.checkbox} />
            <Input id="Todo-input" placeholder='Enter item...' defaultValue={task} onBlur={handleItem} style={{
                textDecoration: isChecked ? 'line-through' : ''
            }} />
            <div className={styles.actions} onClick={handleClose} >
                <Image src={closeIcon} alt="" width={22} height={22} className={styles.closeIcon} />
            </div>
        </div>
    )
}

export default Item